pub struct CountProjectsStatus500Headers {
pub link: Option<String>,
pub rate_limit: Option<String>,
pub rate_limit_policy: Option<String>,
pub retry_after: Option<String>,
pub x_request_id: Option<String>,
}Expand description
Documented response headers for beginInvitationSso Status403.
Fields
link: Option<String>Optional related resources.
rate_limit: Option<String>Optional rate limit information.
rate_limit_policy: Option<String>Optional rate limit policy.
retry_after: Option<String>Optional retry delay or HTTP date.
x_request_id: Option<String>Application request identifier.
Implementations
Sourceimpl BeginInvitationSsoStatus403Headers
impl BeginInvitationSsoStatus403Headers
Sourcepub fn from_headers(headers: &HeaderMap) -> Result<Self, HeaderError>
pub fn from_headers(headers: &HeaderMap) -> Result<Self, HeaderError>
Read the documented headers out of a raw header map.
Sourcepub fn from_response<T>(
response: &ResponseValue<T>,
) -> Result<Self, HeaderError>
pub fn from_response<T>( response: &ResponseValue<T>, ) -> Result<Self, HeaderError>
Read the documented headers out of a returned response value.