pub struct AuthorizedApplication {
pub application: AuthorizedOAuthApplication,
pub authorization_id: String,
pub granted_scopes: Vec<String>,
pub oauth_resource: Option<String>,
pub additional: BTreeMap<String, Value>,
}Fields
application: AuthorizedOAuthApplicationIdentifier of the user’s authorization grant for this application.
granted_scopes: Vec<String>OAuth scope slugs the user has granted to this application.
oauth_resource: Option<String>OAuth resource associated with the grant, or null when no resource is specified.
additional: BTreeMap<String, Value>Trait Implementations
Sourceimpl Clone for AuthorizedApplication
impl Clone for AuthorizedApplication
Sourceimpl Debug for AuthorizedApplication
impl Debug for AuthorizedApplication
Sourceimpl<'de> Deserialize<'de> for AuthorizedApplication
impl<'de> Deserialize<'de> for AuthorizedApplication
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more