pub struct BillingPreviewLine {
pub amount_cents: i64,
pub code: String,
pub kind: BillingPreviewLineKind,
pub name: String,
pub period_end: Option<String>,
pub period_start: Option<String>,
pub units: String,
}Fields
amount_cents: i64code: StringThe fixed-charge code for a fixed charge, the metric code for usage, and the plan code otherwise.
kind: BillingPreviewLineKindname: Stringperiod_end: Option<String>period_start: Option<String>units: StringUnits billed, as a decimal. Units already paid this period are not billed again, so a purchase can bill fewer units than it adds.
Implementations
Sourceimpl BillingPreviewLine
impl BillingPreviewLine
pub fn serialize<__S>(
__self: &BillingPreviewLine,
__serializer: __S,
) -> Result<__S::Ok, __S::Error>where
__S: Serializer,
Sourceimpl<'de> BillingPreviewLine
impl<'de> BillingPreviewLine
pub fn deserialize<__D>(
__deserializer: __D,
) -> Result<BillingPreviewLine, __D::Error>where
__D: Deserializer<'de>,