pub struct DeviceAuthorizeResponse {
pub device_code: String,
pub expires_in: f64,
pub interval: f64,
pub user_code: String,
pub verification_uri: String,
pub verification_uri_complete: String,
pub additional: BTreeMap<String, Value>,
}Fields
device_code: StringOpaque device code to exchange at POST /v1/auth/device/token while waiting for the user to authorize.
expires_in: f64Lifetime of the device code and user code, in seconds.
interval: f64Minimum number of seconds to wait between token polling requests.
user_code: StringCode the user enters at verification_uri to authorize this device.
verification_uri: StringBrowser URL where the user enters user_code and authorizes the device.
verification_uri_complete: StringBrowser URL with user_code included, ready to open or encode as a QR code.
additional: BTreeMap<String, Value>Trait Implementations
Sourceimpl Clone for DeviceAuthorizeResponse
impl Clone for DeviceAuthorizeResponse
Sourceimpl Debug for DeviceAuthorizeResponse
impl Debug for DeviceAuthorizeResponse
Sourceimpl<'de> Deserialize<'de> for DeviceAuthorizeResponse
impl<'de> Deserialize<'de> for DeviceAuthorizeResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more