Module types

Module types 

Structs

Account
AccountDeletedProblem
AccountNotFoundProblem
AccountOwnsOrganizationsProblem
AccountServiceKey
AccountServiceKeyLimitReachedProblem
AccountServiceKeyNotFoundProblem
AgentProfile
AgentProfileAvatarUpload
AgentProfileAvatarUploadFormFields
ApiKey
ApiKeyLimitReachedProblem
ApiKeyNotFoundProblem
ApiKeyRevokedProblem
AppInstallationAssertionInvalidProblem
AppInstallationAssertionReplayedProblem
AppInstallationConfigChangedProblem
AppInstallationDeliveryUnavailableProblem
AssignSmsLineCampaignRequest
AssignVoiceLineProfileRequest
AssignmentExistsProblem
AssignmentNotFoundProblem
Attachment
AttachmentConflictProblem
AttachmentNotFoundProblem
AttachmentNotReadyProblem
AttachmentPage
AttachmentUploadNotReadyProblem
AuthorizedApplication
AuthorizedOAuthApplication
The OAuth application authorized by the authenticated user.
AuthorizedOAuthApplicationRedirectUri
AvailableProjectSlug
BatchUpdateVoiceLineProfileAssignmentsRequest
BatchUpdateVoiceLineProfileAssignmentsResponse
BeginInvitationSsoRequest
BillingNotProvisionedProblem
BillingOperationFailure
BillingOperationResult
BillingPlan
BillingPlanEntitlement
CancelSubscriptionRequest
CancelSubscriptionResponse
CaptchaRequiredProblem
ChangePlanRequest
ClickHouseSqlQueryRequest
CommitAccountProfilePictureRequest
CommitAgentProfileAvatarRequest
ConfigureVoiceProfileOutboundRequest
ConfigureVoiceProfileOutboundResponse
ConfirmAccountPhoneVerificationRequest
ConnectEmailDomainRequest
ConnectTelegramBotRequest
ConnectWhatsappBusinessRequest
CreateAccountServiceKeyRequest
CreateAccountServiceKeyResponse
CreateAgentProfileAvatarUploadRequest
CreateAppInstallationRequestRequest
CreateAppInstallationRequestResponse
CreateDefaultVoiceProfileRequest
CreateOrganizationPaymentMethodCheckoutResponse
CreateOrganizationSetupIntentResponse
CreateOrganizationSsoPortalLinkRequest
CreateOrganizationSsoPortalLinkResponse
CreateProjectApiKeyRequest
CreateProjectApiKeyResponse
CreateProjectRequest
CreateSharedLineAssignmentRequest
CreateVoiceProfileRequest
CreateWebhookDestinationRequest
CreateWebhookDestinationResponse
CreateWhatsappSharedLineAssignmentRequest
CreateWhatsappVoipSenderRequest
CreatedAppInstallationDelivery
DedicatedProjectPlatformSettings
DeleteVoiceProfileOutboundResponse
DeprecatedWebhookApiVersion
DeprecatedWebhookEventCatalog
DeviceAuthorizeResponse
DeviceCodeGrantRequest
DeviceTokenBadRequestResponse
DeviceTokenResponse
DeviceTokenResponseUser
Profile of the authenticated user.
DisableOrganizationSsoRequest
EmailDomainAlreadyConnectedProblem
EmailDomainCapExceededProblem
EntitlementRequiredProblem
ExistingAppInstallationDelivery
FailedBillingOperation
FailedPreconditionProblem
FixedCharge
FixedChargePricing
FixedChargeTier
ForbiddenProblem
GetBillingOverviewResponse
GetMessageMetricsBackfillResponse
GetMessageMetricsSqlSchemaResponse
GetOperationResponse
GetOrganizationBillingOverviewResponse
GetOrganizationPaymentMethodResponse
GetProjectClosureStatusResponse
GetSmsLineCampaignAssignmentResponse
GetWhatsappBusinessVerificationCodeResponse
GetWhatsappSignupConfigResponse
HttpErrorProblem
IdempotencyKeyInvalidProblem
IdempotencyKeyRequiredProblem
IdempotencyKeyReusedProblem
IdempotencyRequestInProgressProblem
IdempotencyUnavailableProblem
ImessageModeDedicatedProblem
InsufficientScopeProblem
InternalErrorProblem
InvalidArgumentProblem
InvalidAttachmentRequestProblem
InvalidAuthContextProblem
InvalidReturnToProblem
InvitationEnterpriseLoginRequest
Invoice
ListAccountServiceKeysResponse
ListAuthorizedApplicationsResponse
ListAuthorizedApplicationsResponseListMetadata
Pagination cursors to pass as after or before in the next list request.
ListBillingPlansResponse
ListInvoicesResponse
ListNumberAreaCodesResponse
ListNumberCountriesResponse
ListOauthScopesResponse
ListProjectApiKeysResponse
ListProjectPlatformsResponse
ListWebhookApiVersionsResponse
ListWebhookEgressAddressesResponse
ListWhatsappAccountPhoneNumbersResponse
MessageMetricsJsonCatalog
MessageMetricsJsonOneOfPathsDiscriminator
MessageMetricsJsonPath
MessageMetricsJsonPathDiscriminator
MessageMetricsJsonResource
MessageMetricsPlatformJsonPaths
MessageMetricsQueryColumn
MessageMetricsQueryStatistics
MessageMetricsSqlCapabilities
MessageMetricsSqlColumn
MessageMetricsSqlLimits
MessageMetricsSqlTable
MeteredUsage
NotAuthenticatedProblem
NumberCountry
Operation
OperationError
OperationNotCancellableProblem
OperationNotFoundProblem
OperationPage
OrganizationAuthenticationRedirect
OrganizationAuthenticationRequest
OrganizationConnectionNotFoundProblem
OrganizationConnectionStatus
OrganizationConnectionStatusMembership
OrganizationConnectionStatusOrganization
OrganizationEnterpriseLoginRequest
OrganizationInvoiceSubject
OrganizationSsoConfiguration
OrganizationSsoConflictProblem
OrganizationSsoDomain
OrganizationSsoNotFoundProblem
OrganizationSsoPreconditionFailedProblem
OrganizationSsoRequiredProblem
OrganizationSubscription
OrganizationSubscriptionEntitlement
OrganizationSyncUnavailableProblem
PayloadTooLargeProblem
PaymentMethod
PaymentProviderNotReadyProblem
PendingBillingOperation
PhoneVerificationCaptcha
ProfilePictureUpload
ProfilePictureUploadFormFields
ProfilePictureUploadRequest
Project
ProjectApiKeyResponse
ProjectClosingProblem
ProjectClosureDomainStatus
ProjectCount
ProjectDeletedProblem
ProjectInvoiceSubject
ProjectNotFoundProblem
ProjectPage
ProjectSubscription
ProjectSubscriptionEntitlement
PurchaseSmsNumberRequest
QueryConcurrencyLimitProblem
QueryMessageMetricsResponse
QueryResourceLimitProblem
RateLimitedProblem
RedeemAppInstallationDeliveryRequest
RefreshTokenGrantRequest
ReplaceVoiceProfileInboundRequest
RequestTimeoutProblem
Resource
ResourceMismatchProblem
ResourceNotFoundProblem
ResourcePage
ResumeSubscriptionRequest
ResumeSubscriptionResponse
RetryEnterpriseLoginRequest
RetryWebhookDeliveryRequest
RetryWebhookDeliveryResponse
RevokeAccountServiceKeyResponse
RotateVoiceProfileOutboundCredentialRequest
RotateVoiceProfileOutboundCredentialResponse
RotateWebhookSigningSecretRequest
RotateWebhookSigningSecretResponse
SelectableWebhookApiVersion
SelectableWebhookEventCatalog
SharedLineAssignment
SharedLineAssignmentPage
SharedLineCapExceededProblem
SharedLinePoolExhaustedProblem
SharedProjectPlatformSettings
SipEndpoint
SipInboundConfiguration
SipInboundCredentials
SipInboundCredentialsWithPassword
SipOutboundAuthentication
SipOutboundAuthenticationPolicy
SipOutboundConfiguration
SipOutboundConnection
SlugTakenProblem
SmsCampaignCapacityExceededProblem
SmsCampaignContextUnavailableProblem
SmsCampaignInvalidRequestProblem
SmsCampaignMutationInProgressProblem
SmsCampaignNotFoundProblem
SmsCampaignNotReadyProblem
SmsCampaignOrganizationMismatchProblem
SmsCampaignReconciliationRequiredProblem
SmsCampaignVersionConflictProblem
SmsLineCampaign
SmsLineNotFoundProblem
SmsLineUnsupportedProblem
SsoSubscriptionRequiredProblem
StartAccountPhoneVerificationRequest
StartAccountPhoneVerificationResponse
StartEnterpriseLoginResponse
SucceededBillingOperation
SupportedPlatform
TelegramProjectDeletedProblem
TelegramProvisionInProgressProblem
UnavailableProjectSlug
UpdateAccountRequest
UpdateAgentProfileRequest
UpdateDefaultVoiceProfileRequest
UpdateOrganizationSsoPolicyRequest
UpdateProjectApiKeyRequest
UpdateProjectRequest
UpdateVoiceProfileInboundRequest
UpdateVoiceProfileOutboundAuthenticationRequest
UpdateVoiceProfileOutboundAuthenticationResponse
UpdateVoiceProfileRequest
UpdateWebhookDestinationRequest
UpstreamFailureProblem
UpstreamTimeoutProblem
UpstreamUnavailableProblem
UsageCharge
UsageChargeFilter
UsageChargeFilterValue
UsageChargePricing
UsageChargeTier
ValidationFailedProblem
ValidationIssue
VoiceDefaultProfileAssignmentForbiddenProblem
VoiceDefaultProfileDeletionForbiddenProblem
VoiceDefaultProfileExistsProblem
VoiceDefaultProfileRequiredProblem
VoiceLineProfileAssignment
VoiceLineProfileAssignmentUpdate
VoiceOutboundConfiguredProblem
VoiceOutboundNotConfiguredProblem
VoiceOutboundOperationPendingProblem
VoiceProfile
VoiceProfileConfiguration
VoiceProfileDirectionConfiguredProblem
VoiceProfileInUseProblem
VoiceProfileInboundConfiguration
VoiceProfileNotFoundProblem
VoiceProfilePage
VoiceProfileVersionConflictProblem
WebhookApiVersionRetirement
WebhookDestination
WebhookDestinationDeletedProblem
WebhookDestinationNotFoundProblem
WebhookDestinationPage
WebhookEventSchema
WebhookEventType
WhatsappAccountDisconnectingProblem
WhatsappAccountPhoneNumber
WhatsappAccountProvisioningProblem
WhatsappBusinessAccount
WhatsappBusinessAccountAlert
WhatsappBusinessAccountRestriction
WhatsappDisplayNameUnavailableProblem
WhatsappModeDedicatedProblem
WhatsappSenderConnectedProblem
WhatsappSenderProvisioningProblem
WhatsappVerificationCodeNotFoundProblem
WhatsappVerificationWindowExpiredProblem
WhatsappVoipSourceNotEligibleProblem
WhatsappVoipSourceReleasingProblem
WhatsappWabaNotConnectedProblem

Enums

AgentProfileAvatarContentType
ApiKeyPermission
AssignSmsLineCampaignBadRequestProblem
AssignSmsLineCampaignConflictProblem
AssignSmsLineCampaignForbiddenProblem
AssignSmsLineCampaignGatewayTimeoutProblem
AssignSmsLineCampaignInternalServerErrorProblem
AssignSmsLineCampaignNotFoundProblem
AssignSmsLineCampaignServiceUnavailableProblem
AssignVoiceLineProfileConflictProblem
AssignVoiceLineProfileForbiddenProblem
AssignVoiceLineProfileGatewayTimeoutProblem
AssignVoiceLineProfileInternalServerErrorProblem
AssignVoiceLineProfileNotFoundProblem
AttachmentNotReadyRetryAfter
BatchUpdateVoiceLineProfileAssignmentsConflictProblem
BatchUpdateVoiceLineProfileAssignmentsForbiddenProblem
BatchUpdateVoiceLineProfileAssignmentsGatewayTimeoutProblem
BatchUpdateVoiceLineProfileAssignmentsInternalServerErrorProblem
BatchUpdateVoiceLineProfileAssignmentsNotFoundProblem
BeginInvitationSsoBadRequestProblem
BeginInvitationSsoForbiddenProblem
BeginInvitationSsoGatewayTimeoutProblem
BeginInvitationSsoInternalServerErrorProblem
BeginInvitationSsoPreconditionFailedProblem
BeginOrganizationAuthenticationBadRequestProblem
BeginOrganizationAuthenticationForbiddenProblem
BeginOrganizationAuthenticationGatewayTimeoutProblem
BeginOrganizationAuthenticationInternalServerErrorProblem
BeginOrganizationAuthenticationPreconditionFailedProblem
BeginOrganizationClosureAuthenticationBadRequestProblem
BeginOrganizationClosureAuthenticationForbiddenProblem
BeginOrganizationClosureAuthenticationGatewayTimeoutProblem
BeginOrganizationClosureAuthenticationInternalServerErrorProblem
BeginOrganizationClosureAuthenticationPreconditionFailedProblem
BeginOrganizationSsoAdmissionBadRequestProblem
BeginOrganizationSsoAdmissionForbiddenProblem
BeginOrganizationSsoAdmissionGatewayTimeoutProblem
BeginOrganizationSsoAdmissionInternalServerErrorProblem
BeginOrganizationSsoAdmissionPreconditionFailedProblem
BillingOperation
Authoritative provisioning state. Poll the operation route while pending.
BillingOperationFailureCode
Stable provider-neutral failure category.
BillingOperationFailureDetail
BillingOperationKind
BillingPlanInterval
CancelOperationForbiddenProblem
CancelOperationGatewayTimeoutProblem
CancelOperationInternalServerErrorProblem
CancelSubscriptionBadRequestProblem
CancelSubscriptionConflictProblem
CancelSubscriptionForbiddenProblem
CancelSubscriptionGatewayTimeoutProblem
CancelSubscriptionInternalServerErrorProblem
CancelSubscriptionServiceUnavailableProblem
CancelSubscriptionUnprocessableEntityProblem
CaptchaProvider
ChangePlanBadRequestProblem
ChangePlanConflictProblem
ChangePlanForbiddenProblem
ChangePlanGatewayTimeoutProblem
ChangePlanInternalServerErrorProblem
ChangePlanServiceUnavailableProblem
ChangePlanUnprocessableEntityProblem
CheckProjectSlugAvailabilityForbiddenProblem
CheckProjectSlugAvailabilityGatewayTimeoutProblem
CheckProjectSlugAvailabilityResponse
CommitAccountProfilePictureBadRequestProblem
CommitAccountProfilePictureForbiddenProblem
CommitAccountProfilePictureGatewayTimeoutProblem
CommitAccountProfilePictureInternalServerErrorProblem
CommitAccountProfilePictureUnprocessableEntityProblem
CommitAgentProfileAvatarBadRequestProblem
CommitAgentProfileAvatarForbiddenProblem
CommitAgentProfileAvatarGatewayTimeoutProblem
CommitAgentProfileAvatarUnprocessableEntityProblem
ConfigureVoiceProfileOutboundBadRequestProblem
ConfigureVoiceProfileOutboundConflictProblem
ConfigureVoiceProfileOutboundForbiddenProblem
ConfigureVoiceProfileOutboundGatewayTimeoutProblem
ConfigureVoiceProfileOutboundInternalServerErrorProblem
ConfigureVoiceProfileOutboundUnprocessableEntityProblem
ConfirmAccountPhoneVerificationForbiddenProblem
ConfirmAccountPhoneVerificationGatewayTimeoutProblem
ConfirmAccountPhoneVerificationInternalServerErrorProblem
ConnectEmailDomainBadRequestProblem
ConnectEmailDomainConflictProblem
ConnectEmailDomainForbiddenProblem
ConnectEmailDomainGatewayTimeoutProblem
ConnectEmailDomainInternalServerErrorProblem
ConnectEmailDomainServiceUnavailableProblem
ConnectEmailDomainUnprocessableEntityProblem
ConnectTelegramBotBadRequestProblem
ConnectTelegramBotConflictProblem
ConnectTelegramBotForbiddenProblem
ConnectTelegramBotGatewayTimeoutProblem
ConnectTelegramBotInternalServerErrorProblem
ConnectTelegramBotUnprocessableEntityProblem
ConnectWhatsappBusinessBadRequestProblem
ConnectWhatsappBusinessForbiddenProblem
ConnectWhatsappBusinessGatewayTimeoutProblem
ConnectWhatsappBusinessInternalServerErrorProblem
ConnectWhatsappBusinessServiceUnavailableProblem
ConnectWhatsappBusinessUnprocessableEntityProblem
CountProjectsForbiddenProblem
CountProjectsGatewayTimeoutProblem
CreateAccountProfilePictureUploadForbiddenProblem
CreateAccountProfilePictureUploadGatewayTimeoutProblem
CreateAccountProfilePictureUploadInternalServerErrorProblem
CreateAccountServiceKeyBadRequestProblem
CreateAccountServiceKeyForbiddenProblem
CreateAccountServiceKeyGatewayTimeoutProblem
CreateAccountServiceKeyInternalServerErrorProblem
CreateAccountServiceKeyUnprocessableEntityProblem
CreateAgentProfileAvatarUploadForbiddenProblem
CreateAgentProfileAvatarUploadGatewayTimeoutProblem
CreateAppInstallationRequestConflictProblem
CreateAppInstallationRequestGatewayTimeoutProblem
CreateDefaultVoiceProfileConflictProblem
CreateDefaultVoiceProfileForbiddenProblem
CreateDefaultVoiceProfileGatewayTimeoutProblem
CreateDefaultVoiceProfileInternalServerErrorProblem
CreateOrganizationPaymentMethodCheckoutBadRequestProblem
CreateOrganizationPaymentMethodCheckoutForbiddenProblem
CreateOrganizationPaymentMethodCheckoutGatewayTimeoutProblem
CreateOrganizationPaymentMethodCheckoutInternalServerErrorProblem
CreateOrganizationPaymentMethodCheckoutServiceUnavailableProblem
CreateOrganizationPaymentMethodCheckoutUnprocessableEntityProblem
CreateOrganizationSetupIntentBadRequestProblem
CreateOrganizationSetupIntentForbiddenProblem
CreateOrganizationSetupIntentGatewayTimeoutProblem
CreateOrganizationSetupIntentInternalServerErrorProblem
CreateOrganizationSetupIntentUnprocessableEntityProblem
CreateOrganizationSsoPortalLinkBadRequestProblem
CreateOrganizationSsoPortalLinkForbiddenProblem
CreateOrganizationSsoPortalLinkGatewayTimeoutProblem
CreateOrganizationSsoPortalLinkInternalServerErrorProblem
CreateOrganizationSsoPortalLinkPreconditionFailedProblem
CreateOrganizationSsoPortalLinkRequestIntent
Default: sso.
CreateProjectApiKeyBadRequestProblem
CreateProjectApiKeyForbiddenProblem
CreateProjectApiKeyUnprocessableEntityProblem
CreateProjectBadRequestProblem
CreateProjectForbiddenProblem
CreateProjectGatewayTimeoutProblem
CreateProjectUnprocessableEntityProblem
CreateSharedLineAssignmentBadRequestProblem
CreateSharedLineAssignmentConflictProblem
CreateSharedLineAssignmentForbiddenProblem
CreateSharedLineAssignmentGatewayTimeoutProblem
CreateSharedLineAssignmentInternalServerErrorProblem
CreateSharedLineAssignmentServiceUnavailableProblem
CreateSharedLineAssignmentUnprocessableEntityProblem
CreateVoiceProfileConflictProblem
CreateVoiceProfileForbiddenProblem
CreateVoiceProfileGatewayTimeoutProblem
CreateVoiceProfileInternalServerErrorProblem
CreateWebhookDestinationBadRequestProblem
CreateWebhookDestinationForbiddenProblem
CreateWebhookDestinationGatewayTimeoutProblem
CreateWebhookDestinationUnprocessableEntityProblem
CreateWhatsappSharedLineAssignmentBadRequestProblem
CreateWhatsappSharedLineAssignmentConflictProblem
CreateWhatsappSharedLineAssignmentForbiddenProblem
CreateWhatsappSharedLineAssignmentGatewayTimeoutProblem
CreateWhatsappSharedLineAssignmentInternalServerErrorProblem
CreateWhatsappSharedLineAssignmentServiceUnavailableProblem
CreateWhatsappSharedLineAssignmentUnprocessableEntityProblem
CreateWhatsappVoipSenderBadRequestProblem
CreateWhatsappVoipSenderConflictProblem
CreateWhatsappVoipSenderForbiddenProblem
CreateWhatsappVoipSenderGatewayTimeoutProblem
CreateWhatsappVoipSenderInternalServerErrorProblem
CreateWhatsappVoipSenderNotFoundProblem
CreateWhatsappVoipSenderServiceUnavailableProblem
CreateWhatsappVoipSenderUnprocessableEntityProblem
DeleteAccountForbiddenProblem
DeleteAccountGatewayTimeoutProblem
DeleteAccountInternalServerErrorProblem
DeleteProjectBadRequestProblem
DeleteProjectForbiddenProblem
DeleteProjectGatewayTimeoutProblem
DeleteProjectUnprocessableEntityProblem
DeleteVoiceProfileConflictProblem
DeleteVoiceProfileForbiddenProblem
DeleteVoiceProfileForceInput
DeleteVoiceProfileGatewayTimeoutProblem
DeleteVoiceProfileInboundConflictProblem
DeleteVoiceProfileInboundForbiddenProblem
DeleteVoiceProfileInboundGatewayTimeoutProblem
DeleteVoiceProfileInboundInternalServerErrorProblem
DeleteVoiceProfileInternalServerErrorProblem
DeleteVoiceProfileOutboundConflictProblem
DeleteVoiceProfileOutboundForbiddenProblem
DeleteVoiceProfileOutboundGatewayTimeoutProblem
DeleteVoiceProfileOutboundInternalServerErrorProblem
DeleteWebhookDestinationForbiddenProblem
DeleteWebhookDestinationGatewayTimeoutProblem
DeviceTokenRequest
DisableOrganizationSsoBadRequestProblem
DisableOrganizationSsoForbiddenProblem
DisableOrganizationSsoGatewayTimeoutProblem
DisableOrganizationSsoInternalServerErrorProblem
DisableOrganizationSsoPreconditionFailedProblem
DisableOrganizationSsoUnprocessableEntityProblem
DisconnectWhatsappBusinessAccountBadRequestProblem
DisconnectWhatsappBusinessAccountConflictProblem
DisconnectWhatsappBusinessAccountForbiddenProblem
DisconnectWhatsappBusinessAccountGatewayTimeoutProblem
DisconnectWhatsappBusinessAccountInternalServerErrorProblem
DisconnectWhatsappBusinessAccountUnprocessableEntityProblem
DownloadAttachmentForbiddenProblem
DownloadAttachmentGatewayTimeoutProblem
DownloadAttachmentInternalServerErrorProblem
ExistingAppInstallationDeliveryStatus
FixedChargeModel
GetAccountForbiddenProblem
GetAccountGatewayTimeoutProblem
GetAccountInternalServerErrorProblem
GetAgentProfileForbiddenProblem
GetAgentProfileGatewayTimeoutProblem
GetAttachmentForbiddenProblem
GetAttachmentGatewayTimeoutProblem
GetAttachmentInternalServerErrorProblem
GetBillingOperationForbiddenProblem
GetBillingOperationGatewayTimeoutProblem
GetBillingOperationInternalServerErrorProblem
GetBillingOverviewForbiddenProblem
GetBillingOverviewGatewayTimeoutProblem
GetBillingOverviewInternalServerErrorProblem
GetDefaultVoiceProfileForbiddenProblem
GetDefaultVoiceProfileGatewayTimeoutProblem
GetDefaultVoiceProfileInternalServerErrorProblem
GetMessageMetricsBackfillForbiddenProblem
GetMessageMetricsSqlSchemaForbiddenProblem
GetOperationForbiddenProblem
GetOperationGatewayTimeoutProblem
GetOperationInternalServerErrorProblem
GetOrganizationBillingOverviewForbiddenProblem
GetOrganizationBillingOverviewGatewayTimeoutProblem
GetOrganizationBillingOverviewInternalServerErrorProblem
GetOrganizationConnectionStatusForbiddenProblem
GetOrganizationConnectionStatusGatewayTimeoutProblem
GetOrganizationConnectionStatusInternalServerErrorProblem
GetOrganizationPaymentMethodForbiddenProblem
GetOrganizationPaymentMethodGatewayTimeoutProblem
GetOrganizationPaymentMethodInternalServerErrorProblem
GetOrganizationSsoConfigurationBadRequestProblem
GetOrganizationSsoConfigurationForbiddenProblem
GetOrganizationSsoConfigurationGatewayTimeoutProblem
GetOrganizationSsoConfigurationInternalServerErrorProblem
GetOrganizationSsoConfigurationPreconditionFailedProblem
GetProjectClosureStatusForbiddenProblem
GetProjectClosureStatusGatewayTimeoutProblem
GetProjectForbiddenProblem
GetProjectGatewayTimeoutProblem
GetProjectImessagePlatformForbiddenProblem
GetProjectImessagePlatformGatewayTimeoutProblem
GetProjectImessagePlatformInternalServerErrorProblem
GetProjectImessagePlatformServiceUnavailableProblem
GetProjectWhatsappPlatformForbiddenProblem
GetProjectWhatsappPlatformGatewayTimeoutProblem
GetProjectWhatsappPlatformInternalServerErrorProblem
GetProjectWhatsappPlatformServiceUnavailableProblem
GetResourceForbiddenProblem
GetResourceGatewayTimeoutProblem
GetResourceInternalServerErrorProblem
GetSharedLineAssignmentForbiddenProblem
GetSharedLineAssignmentGatewayTimeoutProblem
GetSharedLineAssignmentInternalServerErrorProblem
GetSmsLineCampaignAssignmentConflictProblem
GetSmsLineCampaignAssignmentForbiddenProblem
GetSmsLineCampaignAssignmentGatewayTimeoutProblem
GetSmsLineCampaignAssignmentInternalServerErrorProblem
GetSmsLineCampaignAssignmentNotFoundProblem
GetSmsLineCampaignAssignmentServiceUnavailableProblem
GetVoiceLineProfileAssignmentForbiddenProblem
GetVoiceLineProfileAssignmentGatewayTimeoutProblem
GetVoiceLineProfileAssignmentInternalServerErrorProblem
GetVoiceProfileForbiddenProblem
GetVoiceProfileGatewayTimeoutProblem
GetVoiceProfileInternalServerErrorProblem
GetWebhookDestinationForbiddenProblem
GetWebhookDestinationGatewayTimeoutProblem
GetWebhookEventSchemaForbiddenProblem
GetWebhookEventSchemaGatewayTimeoutProblem
GetWhatsappBusinessAccountForbiddenProblem
GetWhatsappBusinessAccountGatewayTimeoutProblem
GetWhatsappBusinessAccountInternalServerErrorProblem
GetWhatsappBusinessVerificationCodeForbiddenProblem
GetWhatsappBusinessVerificationCodeGatewayTimeoutProblem
GetWhatsappBusinessVerificationCodeInternalServerErrorProblem
GetWhatsappBusinessVerificationCodeNotFoundProblem
GetWhatsappBusinessVerificationCodeUnprocessableEntityProblem
GetWhatsappSharedLineAssignmentForbiddenProblem
GetWhatsappSharedLineAssignmentGatewayTimeoutProblem
GetWhatsappSharedLineAssignmentInternalServerErrorProblem
GetWhatsappSignupConfigForbiddenProblem
GetWhatsappSignupConfigInternalServerErrorProblem
InvoiceKind
What produced the invoice.
InvoicePaymentStatus
Provider-neutral payment status.
InvoiceSubject
JsonValue
ListAccountServiceKeysForbiddenProblem
ListAccountServiceKeysGatewayTimeoutProblem
ListAccountServiceKeysInternalServerErrorProblem
ListAttachmentsForbiddenProblem
ListAttachmentsGatewayTimeoutProblem
ListAttachmentsInternalServerErrorProblem
ListAuthorizedApplicationsForbiddenProblem
ListAuthorizedApplicationsGatewayTimeoutProblem
ListAuthorizedApplicationsInternalServerErrorProblem
ListAuthorizedApplicationsOrder
ListBillingPlansForbiddenProblem
ListBillingPlansGatewayTimeoutProblem
ListBillingPlansInternalServerErrorProblem
ListInvoicesForbiddenProblem
ListInvoicesGatewayTimeoutProblem
ListInvoicesInternalServerErrorProblem
ListNumberAreaCodesForbiddenProblem
ListNumberAreaCodesGatewayTimeoutProblem
ListNumberAreaCodesInternalServerErrorProblem
ListNumberCountriesForbiddenProblem
ListNumberCountriesGatewayTimeoutProblem
ListNumberCountriesInternalServerErrorProblem
ListOauthScopesGatewayTimeoutProblem
ListOperationsForbiddenProblem
ListOperationsGatewayTimeoutProblem
ListOperationsInternalServerErrorProblem
ListProjectApiKeysForbiddenProblem
ListProjectPlatformsForbiddenProblem
ListProjectPlatformsInternalServerErrorProblem
ListProjectsForbiddenProblem
ListProjectsGatewayTimeoutProblem
ListResourcesForbiddenProblem
ListResourcesGatewayTimeoutProblem
ListResourcesInternalServerErrorProblem
ListSharedLineAssignmentsForbiddenProblem
ListSharedLineAssignmentsGatewayTimeoutProblem
ListSharedLineAssignmentsInternalServerErrorProblem
ListVoiceProfilesDefaultInput
ListVoiceProfilesForbiddenProblem
ListVoiceProfilesGatewayTimeoutProblem
ListVoiceProfilesInternalServerErrorProblem
ListWebhookApiVersionsForbiddenProblem
ListWebhookApiVersionsGatewayTimeoutProblem
ListWebhookDestinationsForbiddenProblem
ListWebhookDestinationsGatewayTimeoutProblem
ListWebhookEgressAddressesForbiddenProblem
ListWebhookEventTypesForbiddenProblem
ListWebhookEventTypesGatewayTimeoutProblem
ListWebhookEventTypesResponse
ListWhatsappAccountPhoneNumbersForbiddenProblem
ListWhatsappAccountPhoneNumbersGatewayTimeoutProblem
ListWhatsappAccountPhoneNumbersInternalServerErrorProblem
ListWhatsappSharedLineAssignmentsForbiddenProblem
ListWhatsappSharedLineAssignmentsGatewayTimeoutProblem
ListWhatsappSharedLineAssignmentsInternalServerErrorProblem
MessageMetricsBackfillState
MessageMetricsDirection
MessageMetricsJsonDiscriminator
MessageMetricsJsonPathValue
MessageMetricsPlatform
MessageMetricsSqlTableName
OperationState
OperationType
OrganizationConnectionSyncStatus
OrganizationSsoConfigurationConnectionState
OrganizationSsoConfigurationPolicySyncStatus
OrganizationSsoDomainState
ProfilePictureContentType
ProjectBillingInitialization
ProjectClosureDomain
ProjectCreatedByActorKind
ProjectPlatformSettings
ProvisionImessageDedicatedLineBadRequestProblem
ProvisionImessageDedicatedLineForbiddenProblem
ProvisionImessageDedicatedLineGatewayTimeoutProblem
ProvisionImessageDedicatedLineInternalServerErrorProblem
ProvisionImessageDedicatedLineServiceUnavailableProblem
ProvisionImessageDedicatedLineUnprocessableEntityProblem
ProvisionWhatsappDedicatedLineBadRequestProblem
ProvisionWhatsappDedicatedLineForbiddenProblem
ProvisionWhatsappDedicatedLineGatewayTimeoutProblem
ProvisionWhatsappDedicatedLineInternalServerErrorProblem
ProvisionWhatsappDedicatedLineServiceUnavailableProblem
ProvisionWhatsappDedicatedLineUnprocessableEntityProblem
PurchaseSmsNumberBadRequestProblem
PurchaseSmsNumberForbiddenProblem
PurchaseSmsNumberGatewayTimeoutProblem
PurchaseSmsNumberInternalServerErrorProblem
PurchaseSmsNumberServiceUnavailableProblem
PurchaseSmsNumberUnprocessableEntityProblem
QueryMessageMetricsForbiddenProblem
QueryMessageMetricsGatewayTimeoutProblem
QueryMessageMetricsUnprocessableEntityProblem
RedeemAppInstallationDeliveryGatewayTimeoutProblem
RedeemAppInstallationDeliveryResponse
RefreshOrganizationSsoConnectionBadRequestProblem
RefreshOrganizationSsoConnectionForbiddenProblem
RefreshOrganizationSsoConnectionGatewayTimeoutProblem
RefreshOrganizationSsoConnectionInternalServerErrorProblem
RefreshOrganizationSsoConnectionPreconditionFailedProblem
ReleaseImessageDedicatedLineForbiddenProblem
ReleaseImessageDedicatedLineGatewayTimeoutProblem
ReleaseImessageDedicatedLineInternalServerErrorProblem
ReleaseResourceConflictProblem
ReleaseResourceForbiddenProblem
ReleaseResourceGatewayTimeoutProblem
ReleaseResourceInternalServerErrorProblem
ReleaseSharedLineAssignmentForbiddenProblem
ReleaseSharedLineAssignmentGatewayTimeoutProblem
ReleaseSharedLineAssignmentInternalServerErrorProblem
ReleaseWhatsappDedicatedLineForbiddenProblem
ReleaseWhatsappDedicatedLineGatewayTimeoutProblem
ReleaseWhatsappDedicatedLineInternalServerErrorProblem
ReleaseWhatsappSharedLineAssignmentForbiddenProblem
ReleaseWhatsappSharedLineAssignmentGatewayTimeoutProblem
ReleaseWhatsappSharedLineAssignmentInternalServerErrorProblem
ReplaceVoiceProfileInboundConflictProblem
ReplaceVoiceProfileInboundForbiddenProblem
ReplaceVoiceProfileInboundGatewayTimeoutProblem
ReplaceVoiceProfileInboundInternalServerErrorProblem
ResetAccountProfilePictureBadRequestProblem
ResetAccountProfilePictureForbiddenProblem
ResetAccountProfilePictureGatewayTimeoutProblem
ResetAccountProfilePictureInternalServerErrorProblem
ResetAccountProfilePictureUnprocessableEntityProblem
ResetAgentProfileAvatarBadRequestProblem
ResetAgentProfileAvatarForbiddenProblem
ResetAgentProfileAvatarGatewayTimeoutProblem
ResetAgentProfileAvatarUnprocessableEntityProblem
ResourceState
ResumeSubscriptionBadRequestProblem
ResumeSubscriptionConflictProblem
ResumeSubscriptionForbiddenProblem
ResumeSubscriptionGatewayTimeoutProblem
ResumeSubscriptionInternalServerErrorProblem
ResumeSubscriptionServiceUnavailableProblem
ResumeSubscriptionUnprocessableEntityProblem
RetryOrganizationConnectionSyncForbiddenProblem
RetryOrganizationConnectionSyncGatewayTimeoutProblem
RetryOrganizationConnectionSyncInternalServerErrorProblem
RetryWebhookDeliveryBadRequestProblem
RetryWebhookDeliveryForbiddenProblem
RevokeAccountServiceKeyBadRequestProblem
RevokeAccountServiceKeyForbiddenProblem
RevokeAccountServiceKeyGatewayTimeoutProblem
RevokeAccountServiceKeyInternalServerErrorProblem
RevokeAccountServiceKeyNotFoundProblem
RevokeAccountServiceKeyUnprocessableEntityProblem
RevokeAuthorizedApplicationForbiddenProblem
RevokeAuthorizedApplicationGatewayTimeoutProblem
RevokeAuthorizedApplicationInternalServerErrorProblem
RevokeProjectApiKeyBadRequestProblem
RevokeProjectApiKeyForbiddenProblem
RevokeProjectApiKeyNotFoundProblem
RevokeProjectApiKeyUnprocessableEntityProblem
RotateVoiceProfileOutboundCredentialBadRequestProblem
RotateVoiceProfileOutboundCredentialConflictProblem
RotateVoiceProfileOutboundCredentialForbiddenProblem
RotateVoiceProfileOutboundCredentialGatewayTimeoutProblem
RotateVoiceProfileOutboundCredentialInternalServerErrorProblem
RotateVoiceProfileOutboundCredentialUnprocessableEntityProblem
RotateWebhookSigningSecretBadRequestProblem
RotateWebhookSigningSecretForbiddenProblem
RotateWebhookSigningSecretGatewayTimeoutProblem
RotateWebhookSigningSecretUnprocessableEntityProblem
SelectableWebhookApiVersionStatus
SharedLineAssignmentPlatform
SipAuthenticationAlgorithm
SipTransport
SmsLineCampaignEligibility
SortOrder
StartAccountPhoneVerificationForbiddenProblem
StartAccountPhoneVerificationGatewayTimeoutProblem
StartAccountPhoneVerificationInternalServerErrorProblem
StartEnterpriseLoginRequest
SubscriptionStatus
State of one category’s subscription. Only categories that hold one appear at all, so the overview reports active or past_due; a cancelled category is absent rather than listed as terminated.
TerminalBillingOperation
TimestampOrderBy
UnassignSmsLineCampaignBadRequestProblem
UnassignSmsLineCampaignConflictProblem
UnassignSmsLineCampaignForbiddenProblem
UnassignSmsLineCampaignGatewayTimeoutProblem
UnassignSmsLineCampaignInternalServerErrorProblem
UnassignSmsLineCampaignNotFoundProblem
UnassignSmsLineCampaignServiceUnavailableProblem
UnassignVoiceLineProfileForbiddenProblem
UnassignVoiceLineProfileGatewayTimeoutProblem
UnassignVoiceLineProfileInternalServerErrorProblem
UnavailableProjectSlugReason
UpdateAccountBadRequestProblem
UpdateAccountForbiddenProblem
UpdateAccountGatewayTimeoutProblem
UpdateAccountInternalServerErrorProblem
UpdateAccountUnprocessableEntityProblem
UpdateAgentProfileBadRequestProblem
UpdateAgentProfileForbiddenProblem
UpdateAgentProfileGatewayTimeoutProblem
UpdateAgentProfileUnprocessableEntityProblem
UpdateDefaultVoiceProfileConflictProblem
UpdateDefaultVoiceProfileForbiddenProblem
UpdateDefaultVoiceProfileGatewayTimeoutProblem
UpdateDefaultVoiceProfileInternalServerErrorProblem
UpdateOrganizationSsoPolicyBadRequestProblem
UpdateOrganizationSsoPolicyForbiddenProblem
UpdateOrganizationSsoPolicyGatewayTimeoutProblem
UpdateOrganizationSsoPolicyInternalServerErrorProblem
UpdateOrganizationSsoPolicyPreconditionFailedProblem
UpdateProjectApiKeyBadRequestProblem
UpdateProjectApiKeyForbiddenProblem
UpdateProjectApiKeyNotFoundProblem
UpdateProjectApiKeyUnprocessableEntityProblem
UpdateProjectBadRequestProblem
UpdateProjectForbiddenProblem
UpdateProjectGatewayTimeoutProblem
UpdateProjectUnprocessableEntityProblem
UpdateVoiceProfileConflictProblem
UpdateVoiceProfileForbiddenProblem
UpdateVoiceProfileGatewayTimeoutProblem
UpdateVoiceProfileInboundConflictProblem
UpdateVoiceProfileInboundForbiddenProblem
UpdateVoiceProfileInboundGatewayTimeoutProblem
UpdateVoiceProfileInboundInternalServerErrorProblem
UpdateVoiceProfileInternalServerErrorProblem
UpdateVoiceProfileOutboundAuthenticationConflictProblem
UpdateVoiceProfileOutboundAuthenticationForbiddenProblem
UpdateVoiceProfileOutboundAuthenticationGatewayTimeoutProblem
UpdateVoiceProfileOutboundAuthenticationInternalServerErrorProblem
UpdateWebhookDestinationBadRequestProblem
UpdateWebhookDestinationForbiddenProblem
UpdateWebhookDestinationGatewayTimeoutProblem
UpdateWebhookDestinationUnprocessableEntityProblem
UploadAttachmentBadRequestProblem
UploadAttachmentConflictProblem
UploadAttachmentForbiddenProblem
UploadAttachmentGatewayTimeoutProblem
UploadAttachmentInternalServerErrorProblem
UsageChargeModel
ValidationLocation
VoiceOutboundCredentialRotationMode
VoiceProfileMediaEncryption
WebhookApiVersion
WebhookDestinationStatus
WebhookEventSelection
WebhookEventTypeAudience
WebhookEventWildcard
WhatsappOutboundCapacity
WhatsappPhoneNumberOwnership
WhatsappRestrictionStatus
WhatsappReviewStatus

Type Aliases

AllWebhookEvents
DownloadAttachmentResponse
ImessageHandle
WebhookEgressAddress
WebhookEventTypeList
WebhookEventTypeName